==> connect-framework-1.12.11.jar: reporting/rollbar.clj <==
(ns reporting.rollbar
  (:require [circleci.rollcage.core :as rollcage]
            [clojure.data.json :as json]
            [org.httpkit.client :as http-client]
            [pcf-utils.core :as pcf-utils]))


(def rb-key (System/getenv "ROLLBAR_KEY"))

(def rollcage-client (rollcage/client rb-key {:environment pcf-utils/app-name}))

(rollcage/setup-uncaught-exception-handler rollcage-client)

(defn rb-base
  [message level status error user uuid code]
  {:payload {
             :access_token rb-key
             :data {
                    :body {:message {:body message
                                     :error error
                                     :status status
                                     :user user
                                     :app_id pcf-utils/app-id}}
                    :level level
                    :timestamp (int (/ (System/currentTimeMillis) 1000))
                    :environment pcf-utils/app-name
                    :request {:url "/authenticate"
                              :method "POST"}
                    :notifier {:name "connect-framework"}
                    :person {:id uuid
                             :username user
                             :code code}
                    :language "clojure"}}})

(defn send-rollbar-event
  [body]
  (let [json-body (json/write-str body)]
    (http-client/request {:url "https://api.rollbar.com/api/1/item/"
                          :method :post
                          :body json-body
                          :insecure? true
                          :headers {"Contenet-Type" "application/json"}})))

(defn error
  [message status error user uuid code]
  (let [body (rb-base message "error" status error user uuid code)]
    (send-rollbar-event body)))

(defn info
  [message status error user uuid code]
  (let [body (rb-base message "info" status error user uuid code)]
    (send-rollbar-event body)))

(defn warn
  [message status error user uuid code]
  (let [body (rb-base message "warning" status error user uuid code)]
    (send-rollbar-event body)))

(defn debug
  [message status error user uuid code]
  (let [body (rb-base message "debug" status error user uuid code)]
    (send-rollbar-event body)))

==> connect-framework-1.15.6.jar: reporting/rollbar.clj <==
(ns reporting.rollbar
  (:require [circleci.rollcage.core :as rollcage]
            [clojure.data.json :as json]
            [org.httpkit.client :as http-client]
            [pcf-utils.core :as pcf-utils]))


(def rb-key (System/getenv "ROLLBAR_KEY"))

(def rollcage-client (rollcage/client rb-key {:environment (pcf-utils/app-name)}))

(rollcage/setup-uncaught-exception-handler rollcage-client)

(defn rb-base
  [message level status error user uuid code]
  {:payload {
             :access_token rb-key
             :data {
                    :body {:message {:body message
                                     :error error
                                     :status status
                                     :user user
                                     :app_id (pcf-utils/app-id)}}
                    :level level
                    :timestamp (int (/ (System/currentTimeMillis) 1000))
                    :environment (pcf-utils/app-name)
                    :request {:url "/authenticate"
                              :method "POST"}
                    :notifier {:name "connect-framework"}
                    :person {:id uuid
                             :username user
                             :code code}
                    :language "clojure"}}})

(defn send-rollbar-event
  [body]
  (let [json-body (json/write-str body)]
    (http-client/request {:url "https://api.rollbar.com/api/1/item/"
                          :method :post
                          :body json-body
                          :insecure? true
                          :headers {"Contenet-Type" "application/json"}})))

(defn error
  [message status error user uuid code]
  (let [body (rb-base message "error" status error user uuid code)]
    (send-rollbar-event body)))

(defn info
  [message status error user uuid code]
  (let [body (rb-base message "info" status error user uuid code)]
    (send-rollbar-event body)))

(defn warn
  [message status error user uuid code]
  (let [body (rb-base message "warning" status error user uuid code)]
    (send-rollbar-event body)))

(defn debug
  [message status error user uuid code]
  (let [body (rb-base message "debug" status error user uuid code)]
    (send-rollbar-event body)))
